jdk/test/java/nio/file/Files/walk_file_tree.sh
changeset 6695 0e91810597f9
parent 5506 202f599c92aa
child 7668 d4a77089c587
--- a/jdk/test/java/nio/file/Files/walk_file_tree.sh	Sat Oct 02 12:59:52 2010 +0100
+++ b/jdk/test/java/nio/file/Files/walk_file_tree.sh	Sun Oct 03 19:39:25 2010 +0100
@@ -22,9 +22,9 @@
 #
 
 # @test
-# @bug 4313887
+# @bug 4313887 6907737
 # @summary Unit test for walkFileTree method
 # @build CreateFileTree PrintFileTree SkipSiblings TerminateWalk
 # @run shell walk_file_tree.sh
 
 # if TESTJAVA isn't set then we assume an interactive run.
@@ -84,6 +84,10 @@
 $JAVA TerminateWalk "$ROOT"
 if [ $? != 0 ]; then failures=`expr $failures + 1`; fi
 
+# test maxDepth
+$JAVA MaxDepth "$ROOT"
+if [ $? != 0 ]; then failures=`expr $failures + 1`; fi
+
 # clean-up
 rm -r "$ROOT"
@@ -22,9 +22,9 @@
 # @summary Unit test for walkFileTree method
-# @build CreateFileTree PrintFileTree SkipSiblings TerminateWalk
+# @build CreateFileTree PrintFileTree SkipSiblings TerminateWalk MaxDepth
 # @run shell walk_file_tree.sh
 